@@ -16,6 +16,10 @@ def test_bases():
     assert basicco.Base()
     assert "__weakref__" in basicco.Base.__slots__
 
+    assert basicco.SlottedBaseMeta
+    assert basicco.SlottedBase
+    assert basicco.SlottedBase()
+
 
 if __name__ == "__main__":
     pytest.main()
